@@ -1,6 +1,11 @@
 #!/bin/sh
 set -e
 
+# Go the sources directory to run commands
+SOURCE="${BASH_SOURCE[0]}"
+DIR=$( cd -P "$( dirname "$SOURCE" )" >/dev/null 2>&1 && pwd )
+cd $DIR
+
 echo "clean-up"
 rm -rf ./*/nam ./*/txt ./*/glyphs/*.plist
 
